# - Locate OpenTHREADS include paths and libraries
# This module defines:
#  OPENTHREADS_INCLUDE_DIR       - where to find includes.
#  OPENTHREADS_LIBRARIES         - the libraries to link against to use OpenTHREADS.
#  OPENTHREADS_LIBRARIES_DEBUG   - the libraries to link against to use OpenTHREADS debug.
#  OPENTHREADS_LIBRARIES_RELEASE - the libraries to link against to use OpenTHREADS optimized.
#  OPENTHREADS_DEFINITIONS       - definitions to use when compiling code that uses OpenTHREADS.
#  OPENTHREADS_FOUND             - If false, don't try to use it
#

FIND_PATH(OPENTHREADS_INCLUDE_DIR OpenThreads/Thread
	PATHS ${CMAKE_HOME_DIRECTORY}/../OpenThreads/include /usr/local/include "$ENV{OPENTHREADS_INCLUDE_DIR}" "$ENV{OPENTHREADS_ROOT}/include" 
	PATH_SUFFIXES include
	)

IF(WIN32)
FIND_LIBRARY(OPENTHREADS_LIBRARY_RELEASE OpenThreadsWin32 
		PATHS ${CMAKE_HOME_DIRECTORY}/../OpenThreads/lib/win32 "$ENV{OPENTHREADS_ROOT}/lib/win32" 
		)
ELSE(WIN32)
FIND_LIBRARY(OPENTHREADS_LIBRARY_RELEASE OpenThreads 
		PATHS ${CMAKE_HOME_DIRECTORY}/../OpenThreads/lib/Linux32 /usr/local/lib "$ENV{OPENTHREADS_ROOT}/lib" 
		)
ENDIF(WIN32)

IF(WIN32)
FIND_LIBRARY(OPENTHREADS_LIBRARY_DEBUG OpenThreadsWin32D 
		PATHS ${CMAKE_HOME_DIRECTORY}/../OpenThreads/lib/win32 "$ENV{OPENTHREADS_ROOT}/lib/win32" 
		)
ELSE(WIN32)
FIND_LIBRARY(OPENTHREADS_LIBRARY_DEBUG OpenThreadsD
		PATHS ${CMAKE_HOME_DIRECTORY}/../OpenThreads/lib/Linux32 /usr/local/lib "$ENV{OPENTHREADS_ROOT}/lib" 
		)
ENDIF(WIN32)


IF(OPENTHREADS_LIBRARY_DEBUG)
   SET(OPENTHREADS_LIBRARIES 
      optimized ${OPENTHREADS_LIBRARY_RELEASE}
      debug ${OPENTHREADS_LIBRARY_DEBUG} 
   )
ELSE(OPENTHREADS_LIBRARY_DEBUG)
   SET(OPENTHREADS_LIBRARIES         ${OPENTHREADS_LIBRARY_RELEASE})
ENDIF(OPENTHREADS_LIBRARY_DEBUG)

IF(OPENTHREADS_INCLUDE_DIR)
	SET(OPENTHREADS_FOUND "YES" )
ENDIF(OPENTHREADS_INCLUDE_DIR)

MARK_AS_ADVANCED(
   OPENTHREADS_INCLUDE_DIR
   OPENTHREADS_LIBRARY_RELEASE
   OPENTHREADS_LIBRARY_DEBUG
) 
